from pyecharts.charts import*
#条形图
def _bar(x,y,n,n2):
    dexbname=Bar()
    dexbname.add_xaxis(x)
    dexbname.add_yaxis(n,y)
    dexbname.render("{}.html".format(n2))
#线形图
def _line(x,y,n,n2):
    dexlname=Line()
    dexlname.add_xaxis(x)
    dexlname.add_yaxis(n,y)
    dexlname.render("{}.html".format(n2))



# 按比分配 a份数 b份数 总数量
def than(a, b, s):
    oneone = s / (a + b) * a
    twotwo = s / (a + b) * b
    return oneone, twotwo


# 圆环 内半径 外半径 面积或周长
def ring(r, R, SC):
    if SC == "C":
        return 2 * 3.14 * r + 2 * 3.14 * R
    elif SC == "S":
        return 3.14 * (R ** 2 - r ** 2)
    else:
        return "请检查参数！"


# 圆中方 半径 判断
def ci_sq(r, judge):
    if judge == 1:
        return 2 * r ** 2
    elif judge == 2:
        return 3.14 * r ** 2
    elif judge == 3:
        return 1.14 * r ** 2
    else:
        return "请检查参数！"


# 方中圆 半径 判断
def sq_ci(r, judge):
    if judge == 1:
        return 4 * r ** 2
    elif judge == 2:
        return 3.14 * r ** 2
    elif judge == 3:
        return 0.86 * r ** 2
    else:
        return "请检查参数"


# 方中圆中方，圆中方中园规律：最外面的图形的面积是最里面的2倍

# 扇形面积 半径 圆心角 周长或面积
def sector(r, Center_angle, SC):
    if SC == "S":
        return 3.14 * r ** 2 * Center_angle / 360
    elif SC == "C":
        return (2 * 3.14 * r * Center_angle / 360) + (2 * r)
    else:
        return "请检查参数"


#计算BMI 身高 体重
def BMI(h,w):
    return w*10000/h**2


#勾股定理求边 直角边1 直角边2 斜边
def thag(ras1,ras2,hyp):
    if ras1 == "x" and ras2 != "x" and hyp !="x":
        return (hyp**2-ras2**2)**0.5
    elif ras2 == "x" and ras1 != "x" and hyp !="x":
        return (hyp**2-ras1**2)**0.5
    elif hyp == "x" and ras1!= "x" and ras2 !="x":
        return (ras1**2+ras2**2)**0.5
    else:
        return "请检查参数"

#和差问题
def hecha(he,cha,first,second):
    if he == "x" and cha != "x" and first != "x" and second != "x":
        return first + second
    elif he != "x" and cha == "x" and first != "x" and second != "x":
        if first >= second:
            return first - second
        else:
            return second - first
    elif he != "x" and cha != "x" and first == "x" and second == "x":
        return (he+cha)/2,(he-cha)/2
    else:
        return "请检查参数"

#阶乘问题
def ntime(num):
    if num == 1:
        return 1
    elif num == 0:
        return 1
    else:
        return ntime(num - 1) * num

#相遇问题
def meet(V1,V2,S):
    return S/(V1+V2)


#2021.6.18开始制作(cwx)
#python的AI效果库
import pygame,sys,time,random
#代码雨
def rain(screen):
    scene=1
    FONT_PX = 15
    font = pygame.font.SysFont("123.ttf", 25)
    bg_suface = pygame.Surface((800, 720), flags=pygame.SRCALPHA)
    bg_suface.fill(pygame.Color(0, 0, 0, 28))
    screen.fill((0, 0, 0))
    letter = ['q', 'w', 'e', 'r', 't', 'y', 'u', 'i', 'o', 'p', 'a', 's', 'd', 'f', 'g', 'h', 'j', 'k', 'l', 'z', 'x', 'c',
              'v', 'b', 'n', 'm',0,1,2,3,4,5,6,7,8,9]
    texts = [
    font.render(str(letter[i]), True, (0, 255, 0)) for i in range(36)
    ]
    # 按屏幕的宽带计算可以在画板上放几列坐标并生成一个列表
    column = int(800 / FONT_PX)
    drops = [0 for i in range(column)]
    flag = False
    while scene == 1:
        # 从队列中获取事件
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                pygame.quit()
                sys.exit()
            elif event.type == pygame.KEYDOWN:
                # if event.key == pygame.K_q:
                #     flag = True
                scene = 2
                break
        if scene == 2:
            break
        # if scene==2 and flag == True:
        #     pygame.quit()
        #     sys.exit()
        #     break
        # if scene==2 and flag == False:
        #     break

        # 将暂停一段给定的毫秒数
        pygame.time.delay(30)

        # 重新编辑图像第二个参数是坐上角坐标
        screen.blit(bg_suface, (0, 0))
        for i in range(len(drops)):
            text = random.choice(texts)

            # 重新编辑每个坐标点的图像
            screen.blit(text, (i * FONT_PX, drops[i] * FONT_PX))

            drops[i] += 1
            if drops[i] * 10 > 720 or random.random() > 0.95:
                drops[i] = 0
        pygame.display.flip()
#退出事件
def q():
    for event in pygame.event.get():
        if event == pygame.QUIT:
            pygame.quit()
            sys.exit(0)
#动态字 已渲染文本 模式 屏幕
def wtext(text,num,screen):
    if num == 1:#x减少y减少
        x=random.randint(600,900)
        y=random.randint(400,600)
        for i in range(1000):
            q()
            x-=0.1
            y-=0.1
            screen.blit(text,(x,y))
            pygame.display.update()
            screen.fill((0,0,0))
            time.sleep(0.001)
    if num == 2:#x增加y减少
        x=random.randint(100,700)
        y=random.randint(400,600)
        for i in range(1000):
            q()
            x+=0.1
            y-=0.1
            screen.blit(text,(x,y))
            pygame.display.update()
            screen.fill((0,0,0))
            time.sleep(0.001)
    if num == 3:#x增加y增加
        x=random.randint(100,700)
        y=random.randint(100,500)
        for i in range(1000):
            q()
            x+=0.1
            y+=0.1
            screen.blit(text,(x,y))
            pygame.display.update()
            screen.fill((0,0,0))
            time.sleep(0.001)
    if num == 4:#x减少y增加
        x=random.randint(600,900)
        y=random.randint(100,500)
        for i in range(1000):
            q()
            x-=0.1
            y+=0.1
            screen.blit(text,(x,y))
            pygame.display.update()
            screen.fill((0,0,0))
            time.sleep(0.001)
    if num == 5:#乱转，特别推荐！！！！！！！！
        for i in range(1000):
            q()
            x=random.randint(0,1000)
            y=random.randint(0,600)
            screen.blit(text,(x,y))
            pygame.display.update()
            screen.fill((0,0,0))
            time.sleep(0.001)


import requests
import json
def get_api(http,*w):
	s = requests.Session()
	header = {'Accept': 'application/json, text/plain, */*', 'Accept-Encoding': 'gzip, deflate',
			  'Accept-Language': 'zh-CN,zh;q=0.9,en;q=0.8,en-GB;q=0.7,en-US;q=0.6',
			  'Cookie': 'xesId=b524835904a4a420cba3dde34890bade; user-select=scratch;  xes_run_token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJpc3MiOiIuY29kZS54dWVlcnNpLmNvbSIsImF1ZCI6Ii5jb2RlLnh1ZWVyc2kuY29tIiwiaWF0IjoxNjAxODA5NDcxLCJuYmYiOjE2MDE4MDk0NzEsImV4cCI6MTYwMTgyMzg3MSwidXNlcl9pZCI6bnVsbCwidWEiOiJNb3ppbGxhXC81LjAgKFdpbmRvd3MgTlQgMTAuMDsgV2luNjQ7IHg2NCkgQXBwbGVXZWJLaXRcLzUzNy4zNiAoS0hUTUwsIGxpa2UgR2Vja28pIENocm9tZVwvODUuMC40MTgzLjEyMSBTYWZhcmlcLzUzNy4zNiBFZGdcLzg1LjAuNTY0LjY4IiwiaXAiOiIxMTIuNDkuNzIuMTc1In0.9bXcb813GhSPhoUJkezZpV8O50ynm0hhYvszNyczznQ; prelogid=ef8f6d12febabf75bf9599744b73c6f5; xes-code-id=87f66376f1afd34f70339baeca61b7a1.8dbd833da9122d69a17f91054066dbb3; X-Request-Id=82f1c3968c8ff01ee151a0413f56aa84; Hm_lpvt_a8a78faf5b3e92f32fe42a94751a74f1=1601809487',
			  'Host': 'code.xueersi.com', 'Proxy-Connection': 'keep-alive',
			  'Referer': 'http://code.xueersi.com/space/11909587',
			  'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/85.0.4183.121 Safari/537.36 Edg/85.0.564.68'}
	total = json.loads(_nice(s.get(http, headers=header).text))
	return total
def get_data():
    import time
    head={"User-Agent":"Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.164 Safari/537.36"}
    a=getCookies()
    num=a.index("stu_id=")+7
    id=""
    for i in range(num,num+100):
        if a[i]!=";":
            id=id+a[i]
        else:
           break
    cwx=requests.get("https://code.xueersi.com/api/space/profile?user_id={}".format(id),headers=head)
    cwx.encoding = "UTF-8"
    soup=bs4.BeautifulSoup(cwx.text,"lxml")
    d=soup.find(name="p").text
    _dic={}
    _dic["你的id"]=id
    _dic["你的粉丝量"]=d[d.find("fans")+6:d.find("follows")-2]
    _dic["你的关注量"]=d[d.find("follows")+9:d.find("disabled")-2]
    _dic["你的姓名"]=get_api("https://code.xueersi.com/api/space/profile?user_id="+id)["data"]["realname"]
    _dic["你的个性签名"]=get_api("https://code.xueersi.com/api/space/profile?user_id="+id)["data"]["signature"]
    return _dic


from turtle import*
from time import*
#定义3D画笔               x y z 焦距
#z不能为0
def go_3(x,y,z,focal_length):
    goto(focal_length*(x/z),focal_length*(y/z))
#生成金箍棒    长 旋转次数 旋转角度
def summon_GC(l,rn,j):
    color("red")
    forward(0-(l/4))
    color("yellow")
    forward(0-(l/4))
    penup()
    forward(l/2)
    pendown()
    color("red")
    forward(l/4)
    color("yellow")
    forward(l/4)
    if rn == 0 or j == 0:
        pass
    else:
        Screen().tracer(0)
        for i in range(rn):
            clear()
            color("red")
            forward(0-(l/4))
            color("yellow")
            forward(0-(l/4))
            penup()
            forward(l/2)
            pendown()
            color("red")
            forward(l/4)
            color("yellow")
            forward(l/4)
            left(j)
            Screen().update()
#定义计时器 持续时间 间隔秒数  长度
def timecount(time,spit,spittime,h):
    speed(0)
    ttttttt = 0
    while ttttttt < time:
        ttttttt += spittime
        sleep(spit)
        print(ttttttt)
        forward(h*spittime)
#画五角星    x坐标 y坐标 大小 是否填充，颜色
def draw_star(x,y,h,fill,c):
    speed(0)
    ht()
    pencolor(c)
    color(c)
    if fill == 0:
        penup()
        goto(x,y)
        forward(150)
        pendown()
        for i in range(5):
            forward(h)
            right(144)
    else:
        penup()
        goto(x,y)
        forward(150)
        pendown()
        begin_fill()
        for i in range(5):
            forward(h)
            right(144)
        end_fill()
#闪光字 内容 时间
def colortext(text, t):
    import random
    colcolcol = [31, 32, 33, 34, 35, 36, 37, 91, 92, 93, 94, 95, 96, 97]
    import time
    import sys
    times = int(t / 0.1)
    for i in range(times):
        print("\033[{}m{}".format(random.choice(colcolcol), text))
        time.sleep(0.1)
        sys.stdout.write('\033[2J\033[00H')


import setuptools
setuptools.setup(
    name='dl2',
    version='0.21.816',
    author='Wenxin Chen',
    author_email='minecraft_cwx@163.com',
    description='凋零工作室二代库，拥有数学、画图拓展、生成HTML文件等模块，在一代的基础上更新了不少',
    ong_descripition_content_type="text/markdown",
    url='https://github.com/',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)